TableInvalidationTracker class final

Constructors

TableInvalidationTracker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportTablesChanged(Set<String> affectedTables) → void
toString() String
A string representation of this object.
inherited
watchTables(Set<String> affectedTables) Stream<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited