SelectRunner<T> class
final
Constructors
-
SelectRunner({required SqliteNowDatabase database, required Set<
String> affectedTables, required Future<List< query()})T> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asList(
) → Future< List< T> > -
asOne(
) → Future< T> -
asOneOrNull(
) → Future< T?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
watch(
) → Stream< List< T> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited